@@ -1,4 +1,4 @@
-# $Id: Article.pm,v 1.5 2003/09/14 08:09:43 cvspub Exp $
+# $Id: Article.pm,v 1.6 2003/09/14 20:02:51 cvspub Exp $
 package WWW::Google::Groups::Article;
 use strict;
 our $VERSION = '0.01';
@@ -7,9 +7,8 @@ use Email::Simple;
 
 sub new {
     my ($pkg, $message) = @_;
-    return Email::Simple->new($$message) if $$message;
-    undef;
+    return $$message ? Email::Simple->new($$message) : undef;
 }
 
-
+1;
 __END__
