@@ -1,4 +1,4 @@
-# $Id: test.pl,v 1.8 2003/09/14 08:29:22 cvspub Exp $
+# $Id: test.pl,v 1.11 2003/09/14 20:19:13 cvspub Exp $
 use Test::More qw(no_plan);
 ok(1);
 
@@ -8,8 +8,8 @@ BEGIN {
     print "The test needs internet connection. Be sure to get connected, or you will get several error messages.\n";
 
     use_ok 'WWW::Google::Groups';
-    $target = 'alt.0';
-    $group = 'alt.0';
+    $group = 'comp.lang.perl.misc';
+    $target = $group;
     open F, ".proxy";
     chomp ($proxy=<F>);
     close F;
@@ -22,6 +22,22 @@ END{
 
 
 
+$agent = new WWW::Google::Groups(
+				 server => 'http://groups.google.com',
+				 proxy => $proxy,
+				 );
+
+ok($agent->save2mbox(
+		     group => $group,
+		     starting_thread => 0,
+#		     max_article_count => 2,
+		     max_thread_count => 2,
+		     target_mbox => $target,
+	       ));
+ok(-f $target);
+
+#__END__
+
 $agent = new WWW::Google::Groups(
 				 server => 'http://groups.google.com',
 				 proxy => $proxy,
@@ -33,6 +49,7 @@ ok(ref($group));
 
 if( $thread = $group->next_thread() ){
     ok(ref($thread));
+
     $article = $thread->next_article();
     ok(ref($article));
 
@@ -41,15 +58,6 @@ if( $thread = $group->next_thread() ){
     ok($article->body);
 }
 
-ok($agent->save2mbox(
-		     group => $group,
-		     starting_thread => 0,
-		     max_article_count => 2,
-#		     max_thread_count => 2,
-		     target_mbox => $target,
-	       ));
-ok(-f $target);
-
 
 
 
